## `valency-anndata` methods

### ::: valency_anndata.tools.recipe_polis

### ::: valency_anndata.tools.kmeans

### ::: valency_anndata.tools.pacmap

### ::: valency_anndata.tools.localmap

## `scanpy` methods (inherited)

!!! note

    These methods are simply quick convenience wrappers around methods in `scanpy`, a tool for single-cell gene expression. They will use terms like "cells", "genes" and "counts", but you can think of these as "participants", "statements" and "votes". 

See [scanpy.tl][] for more methods you can experiment with via the `val.scanpy.tl` namespace.

### ::: valency_anndata.tools.pca

### ::: valency_anndata.tools.tsne

### ::: valency_anndata.tools.umap

### ::: valency_anndata.tools.leiden